.. -*- Mode: rst -*-

.. -*- Mode: rst -*-

..
   |PyMetrologyUrl|
   |PyMetrologyHomePage|_
   |PyMetrologyDoc|_
   |PyMetrology@github|_
   |PyMetrology@readthedocs|_
   |PyMetrology@readthedocs-badge|
   |PyMetrology@pypi|_

.. |ohloh| image:: https://www.openhub.net/accounts/230426/widgets/account_tiny.gif
   :target: https://www.openhub.net/accounts/fabricesalvaire
   :alt: Fabrice Salvaire's Ohloh profile
   :height: 15px
   :width:  80px

.. |PyMetrologyUrl| replace:: https://pymetrology.fabrice-salvaire.fr

.. |PyMetrologyHomePage| replace:: PyMetrology Home Page
.. _PyMetrologyHomePage: https://pymetrology.fabrice-salvaire.fr

.. |PyMetrology@readthedocs-badge| image:: https://readthedocs.org/projects/pymetrology/badge/?version=latest
   :target: http://pymetrology.readthedocs.org/en/latest

.. |PyMetrology@github| replace:: https://github.com/FabriceSalvaire/PyMetrology
.. .. _PyMetrology@github: https://github.com/FabriceSalvaire/PyMetrology

.. |PyMetrology@pypi| replace:: https://pypi.python.org/pypi/PyMetrology
.. .. _PyMetrology@pypi: https://pypi.python.org/pypi/PyMetrology

.. |Build Status| image:: https://travis-ci.org/FabriceSalvaire/PyMetrology.svg?branch=master
   :target: https://travis-ci.org/FabriceSalvaire/PyMetrology
   :alt: PyMetrology build status @travis-ci.org

.. |Pypi Version| image:: https://img.shields.io/pypi/v/PyMetrology.svg
   :target: https://pypi.python.org/pypi/PyMetrology
   :alt: PyMetrology last version

.. |Pypi License| image:: https://img.shields.io/pypi/l/PyMetrology.svg
   :target: https://pypi.python.org/pypi/PyMetrology
   :alt: PyMetrology license

.. |Pypi Python Version| image:: https://img.shields.io/pypi/pyversions/PyMetrology.svg
   :target: https://pypi.python.org/pypi/PyMetrology
   :alt: PyMetrology python version

..  coverage test
..  https://img.shields.io/pypi/status/Django.svg
..  https://img.shields.io/github/stars/badges/shields.svg?style=social&label=Star

.. End
.. -*- Mode: rst -*-

.. |Python| replace:: Python
.. _Python: http://python.org

.. |PyPI| replace:: PyPI
.. _PyPI: https://pypi.python.org/pypi

.. |Numpy| replace:: Numpy
.. _Numpy: http://www.numpy.org

.. |IPython| replace:: IPython
.. _IPython: http://ipython.org

.. |Sphinx| replace:: Sphinx
.. _Sphinx: http://sphinx-doc.org

.. End

============
 PyMetrology
============

|Pypi License|
|Pypi Python Version|

|Pypi Version|

* Quick Link to `Production Branch <https://github.com/FabriceSalvaire/PyMetrology/tree/master>`_
* Quick Link to `Devel Branch <https://github.com/FabriceSalvaire/PyMetrology/tree/devel>`_

Overview
========

What is PyMetrology ?
---------------------

**Note: source code was extracted from PySpice, in development ...**

PyMetrology is a Python module which implements a unit framework.

Where is the Documentation ?
----------------------------

The documentation is available on the |PyMetrologyHomePage|_.

What are the main features ?
----------------------------

* to be completed

How to install it ?
-------------------

Look at the `installation <https://pymetrology.fabrice-salvaire.fr/installation.html>`_ section in the documentation.

Credits
=======

Authors: `Fabrice Salvaire <http://fabrice-salvaire.fr>`_

News
====

.. -*- Mode: rst -*-


.. no title here

V0 2017-10-01
-------------

Started project

.. End

.. End
